DensityOfStates — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# DensityOfStates

The `pyprocar.core.DensityOfStates` class is used to store and manipulate density of states information. Density of states 1d numpy array of energy, (n_energy,n_spin) total densities and projections at each energy. See Density of States for further details.

`pyprocar.core.DensityOfStates`(energies, ...) | A class that contains density of states calculated by the a density functional theory calculation.